# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).



## Unreleased
### ...
- ...

## [1.0.0-alpha] - 2021-02-26

[1.0.0-alpha] https://github.com/ggirelli/ifpd/releases/tag/v1.0.0-alpha  
